==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin.inputs

import com.pulumi.azurenative.dbformysql.inputs.SkuArgs.builder
import com.pulumi.azurenative.dbformysql.kotlin.enums.SkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Billing information related properties of a server.
 * @property name The name of the sku, e.g. Standard_D32s_v3.
 * @property tier The tier of the particular SKU, e.g. GeneralPurpose.
 */
public data class SkuArgs(
    public val name: Output<String>,
    public val tier: Output<Either<String, SkuTier>>,
) : ConvertibleToJava<com.pulumi.azurenative.dbformysql.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.dbformysql.inputs.SkuArgs =
        com.pulumi.azurenative.dbformysql.inputs.SkuArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .tier(
                tier.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var tier: Output<Either<String, SkuTier>>? = null

    /**
     * @param value The name of the sku, e.g. Standard_D32s_v3.
     */
    @JvmName("jynmeibmbtxmhyvo")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("feruuslhtwsddlnn")
    public suspend fun tier(`value`: Output<Either<String, SkuTier>>) {
        this.tier = value
    }

    /**
     * @param value The name of the sku, e.g. Standard_D32s_v3.
     */
    @JvmName("jwlnospqvpxdbtxj")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("oyweyomfewfgslrt")
    public suspend fun tier(`value`: Either<String, SkuTier>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("ppgvpqfvxetfpnfn")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("ucndoocjmqmqiegw")
    public fun tier(`value`: SkuTier) {
        val toBeMapped = Either.ofRight<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tier = tier ?: throw PulumiNullFieldException("tier"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin.inputs

import com.pulumi.azurenative.dbformysql.inputs.SkuArgs.builder
import com.pulumi.azurenative.dbformysql.kotlin.enums.SkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Billing information related properties of a server.
 * @property name The name of the sku, e.g. Standard_D32s_v3.
 * @property tier The tier of the particular SKU, e.g. GeneralPurpose.
 */
public data class SkuArgs(
    public val name: Output<String>,
    public val tier: Output<Either<String, SkuTier>>,
) : ConvertibleToJava<com.pulumi.azurenative.dbformysql.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.dbformysql.inputs.SkuArgs =
        com.pulumi.azurenative.dbformysql.inputs.SkuArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .tier(
                tier.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var tier: Output<Either<String, SkuTier>>? = null

    /**
     * @param value The name of the sku, e.g. Standard_D32s_v3.
     */
    @JvmName("geamivobnahejiwb")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("mpqgpwlbonnutfal")
    public suspend fun tier(`value`: Output<Either<String, SkuTier>>) {
        this.tier = value
    }

    /**
     * @param value The name of the sku, e.g. Standard_D32s_v3.
     */
    @JvmName("lrvgjyohjcbyhcuj")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("kksshmxcuahnynsp")
    public suspend fun tier(`value`: Either<String, SkuTier>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("wlotddjgruajvkvj")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The tier of the particular SKU, e.g. GeneralPurpose.
     */
    @JvmName("cdvjqueklgdfbteg")
    public fun tier(`value`: SkuTier) {
        val toBeMapped = Either.ofRight<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tier = tier ?: throw PulumiNullFieldException("tier"),
    )
}
